pybdsim documentation
=====================

pybdsim is a Python package to aid in the preparation, running and validation
of BDSIM models.

.. toctree::
   :maxdepth: 2

   licence
   authorship
   installation
   builder
   convert
   compare	     
   data
   data_uproot
   plotting
   fieldmaps
   classes
   support
   version_history
   moduledocs
   developer
	     



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
